@@ -17,7 +17,7 @@ class Component:
         self.custom_id = custom_id
         self.parent = parent
         self.func = func
-        self.timeout = timeout
+        self.timeout = ((datetime.utcnow() - datetime.fromtimestamp(0)).total_seconds() + timeout)
         self.created_at = datetime.utcnow()
         self.is_single_use = is_single_use
 
